@@ -514,7 +514,7 @@ svymean<-function(x, design,na.rm=FALSE,...){
   UseMethod("svymean",design)
 }
 
-svymean.survey.design<-function(x,design, na.rm=FALSE,deff=FALSE,...){
+svymean.survey.design<-function(x,design, na.rm=FALSE,deff=FALSE, influence=FALSE,...){
 
   if (!inherits(design,"survey.design"))
     stop("design is not a survey design")
@@ -550,7 +550,9 @@ svymean.survey.design<-function(x,design, na.rm=FALSE,deff=FALSE,...){
   v<-svyCprod(x*pweights/psum,design$strata,design$cluster[[1]], design$fpc,
               design$nPSU,design$certainty, design$postStrata)
   attr(average,"var")<-v
-  attr(average,"statistic")<-"mean"
+    attr(average,"statistic")<-"mean"
+  if(influence)
+    attr(average, "influence")<-x*pweights/psum
   class(average)<-"svystat"
   if (is.character(deff) || deff){
     nobs<-NROW(design$cluster)
@@ -598,6 +600,10 @@ vcov.svystat<-function(object,...){
   as.matrix(attr(object,"var"))
 }
 
+influence.svystat<-function(object,...){
+  attr(object,"influence")
+}
+
 SE.svystat<-function(object,...){
  v<-vcov(object)
  if (!is.matrix(v) || NCOL(v)==1) sqrt(v) else sqrt(diag(v))
@@ -627,7 +633,7 @@ svytotal<-function(x,design,na.rm=FALSE,...){
   .svycheck(design)
   UseMethod("svytotal",design)
 }
-svytotal.survey.design<-function(x,design, na.rm=FALSE, deff=FALSE,...){
+svytotal.survey.design<-function(x,design, na.rm=FALSE, deff=FALSE,influence=FALSE,...){
 
   if (!inherits(design,"survey.design"))
     stop("design is not a survey design")
@@ -661,7 +667,10 @@ svytotal.survey.design<-function(x,design, na.rm=FALSE, deff=FALSE,...){
   attr(total, "var")<-v<-svyCprod(x/design$prob,design$strata,
                                   design$cluster[[1]], design$fpc,
                                   design$nPSU,design$certainty,design$postStrata)
-  attr(total,"statistic")<-"total"
+    attr(total,"statistic")<-"total"
+    if (influence){
+        attr(total,"influence")<-x/design$prob
+        }
   if (is.character(deff) || deff){
     vsrs<-svyvar(x,design)*sum(weights(design)^2)
     vsrs<-vsrs*(N-NROW(design$cluster))/N
@@ -727,7 +736,7 @@ svyquantile<-function(x,design,quantiles,...) UseMethod("svyquantile", design)
 svyquantile.survey.design<-function(x,design,quantiles,alpha=0.05,
                                     ci=FALSE, method="linear",f=1,
                                     interval.type=c("Wald","score","betaWald"),
-                                    na.rm=FALSE,se=ci, ties=c("discrete","rounded"), df=Inf,...){
+                                    na.rm=FALSE,se=ci, ties=c("discrete","rounded"), df=NULL,...){
     if (inherits(x,"formula"))
       x<-model.frame(x ,model.frame(design), na.action=na.pass)
     else if(typeof(x) %in% c("expression","symbol"))
@@ -1086,12 +1095,12 @@ svytable.survey.design<-function(formula, design, Ntotal=NULL, round=FALSE,...){
   tbl
 }
 
-svycoxph<-function(formula,design,subset=NULL,...){
+svycoxph<-function(formula,design,subset=NULL,rescale=TRUE,...){
   .svycheck(design)
   UseMethod("svycoxph",design)
 }
 
-svycoxph.survey.design<-function(formula,design,subset=NULL,...){
+svycoxph.survey.design<-function(formula,design, subset=NULL, rescale=TRUE, ...){
     subset<-substitute(subset)
     subset<-eval(subset, model.frame(design),parent.frame())
     if (!is.null(subset))
@@ -1105,6 +1114,7 @@ svycoxph.survey.design<-function(formula,design,subset=NULL,...){
     g$formula<-eval.parent(g$formula)
     g$design<-NULL
     g$var<-NULL
+    g$rescale <- NULL
     if (is.null(g$weights))
       g$weights<-quote(.survey.prob.weights)
     else
@@ -1115,7 +1125,9 @@ svycoxph.survey.design<-function(formula,design,subset=NULL,...){
     g$model <- TRUE
     
     ##need to rescale weights for stability
-    data$.survey.prob.weights<-(1/design$prob)/mean(1/design$prob)
+    ## unless the user doesn't want to
+    if (rescale)
+        data$.survey.prob.weights<-(1/design$prob)/mean(1/design$prob)
     if (!all(all.vars(formula) %in% names(data))) 
         stop("all variables must be in design= argument")
     g<-with(list(data=data), eval(g))
@@ -1245,12 +1257,13 @@ anova.svycoxph<-function(object,...){
     stop("No anova method for survey models")
 }
 
-svyglm<-function(formula, design, ...){
+svyglm<-function(formula, design,subset=NULL,family=stats::gaussian(),start=NULL, ...){
   .svycheck(design)
   UseMethod("svyglm",design)
 }
 
-svyglm.survey.design<-function(formula,design,subset=NULL,...){
+svyglm.survey.design<-function(formula,design,subset=NULL, family=stats::gaussian(),start=NULL,
+                               rescale=TRUE,..., deff=FALSE, influence=FALSE){
 
       subset<-substitute(subset)
       subset<-eval(subset, model.frame(design), parent.frame())
@@ -1260,9 +1273,13 @@ svyglm.survey.design<-function(formula,design,subset=NULL,...){
       data<-model.frame(design)
 
       g<-match.call()
-      g$formula<-eval.parent(g$formula)
+    g$formula<-eval.parent(g$formula)
+    g$influence<-NULL
       g$design<-NULL
-      g$var<-NULL
+      g$var <- NULL
+    g$rescale <- NULL
+    g$deff<-NULL
+      g$family<-family
       if (is.null(g$weights))
         g$weights<-quote(.survey.prob.weights)
       else 
@@ -1271,11 +1288,14 @@ svyglm.survey.design<-function(formula,design,subset=NULL,...){
       g[[1]]<-quote(glm)      
 
       ##need to rescale weights for stability in binomial
-      data$.survey.prob.weights<-(1/design$prob)/mean(1/design$prob)
+      ## (unless the user doesn't want to)
+      if (rescale)
+          data$.survey.prob.weights<-(1/design$prob)/mean(1/design$prob)
       if (!all(all.vars(formula) %in% names(data))) 
 	stop("all variables must be in design= argument")
-      g<-with(list(data=data), eval(g))
-      g$naive.cov<-summary(g)$cov.unscaled
+    g<-with(list(data=data), eval(g))
+    summ<-summary(g)
+      g$naive.cov<-summ$cov.unscaled
       
       nas<-g$na.action
       if (length(nas))
@@ -1285,7 +1305,7 @@ svyglm.survey.design<-function(formula,design,subset=NULL,...){
       g$df.residual <- degf(design)+1-length(coef(g)[!is.na(coef(g))])
       
       class(g)<-c("svyglm",class(g))
-      g$call<-sys.call()
+      g$call<-match.call()
       g$call[[1]]<-as.name(.Generic)
       if(!("formula" %in% names(g$call))) {
         if (is.null(names(g$call)))
@@ -1294,6 +1314,21 @@ svyglm.survey.design<-function(formula,design,subset=NULL,...){
           i<-min(which(names(g$call)[-1]==""))
         names(g$call)[i+1]<-"formula"
       }
+
+    if(deff){
+        vsrs<-summ$cov.scaled*mean(data$.survey.prob.weights)/nrow(data)
+        attr(g,"deff")<-g$cov.unscaled/vsrs
+    }
+
+    if (influence){
+        estfun<-model.matrix(g)*resid(g,"working")*g$weights
+        if (g$rank<NCOL(estfun)){
+            estfun<-estfun[,g$qr$pivot[1:g$rank]]
+        }
+        attr(g, "influence")<-estfun%*%g$naive.cov
+    }
+
+    
       g$survey.design<-design 
       g
 }
@@ -1486,7 +1521,26 @@ dBIC<-function(modela,modelM){
 		nstar=NaN
 		}
 	c(p=pm, BIC=wald+pm*log(n)+log(detDelta)+deviance(modelM),neff=nstar)
-	}	
+    }
+
+extractAIC.svrepcoxph<-function (fit, scale, k = 2, ...) .NotYetImplemented()
+extractAIC.svycoxph<-function (fit, scale, k = 2, ...) 
+{
+    Delta<-solve(fit$inv.info, fit$var)
+    deltabar <- mean(diag(Delta))
+    d <- -2*fit$ll[1]
+    c(eff.p = sum(diag(Delta)), AIC = d + k * sum(diag(Delta)), deltabar = deltabar)
+}
+AIC.svycoxph<-function (object, ..., k = 2) 
+{
+    if (length(list(...))) {
+        do.call(rbind, lapply(list(object, ...), extractAIC, 
+            k = k))
+    }
+    else {
+        extractAIC(object, k = k)
+    }
+}
 
 
 confint.svyglm<-function(object,parm,level=0.95,method=c("Wald","likelihood"),ddf=Inf,...){
@@ -1640,45 +1694,47 @@ MASSprofile_glm<-function (fitted, which = 1:p, alpha = 0.01, maxsteps = 10, del
 ###
 
 svymle<-function(loglike, gradient=NULL, design, formulas,
-                 start=NULL, control=list(maxit=1000),
-                 na.action="na.fail", method=NULL,...){
+    start=NULL, control=list(),
+    na.action="na.fail", method=NULL,lower=NULL,upper=NULL,
+    influence=FALSE,...){
   if(is.null(method))
-    method<-if(is.null(gradient)) "Nelder-Mead" else "nlm"
-  
+    method<-if(is.null(gradient)) "Nelder-Mead" else "newuoa"
   if (!inherits(design,"survey.design")) 
-	stop("design is not a survey.design")
+    stop("design is not a survey.design")
   weights<-weights(design)
   wtotal<-sum(weights)
- 
-  if (is.null(control$fnscale))
-      control$fnscale <- -wtotal/length(weights)
-  if (inherits(design, "twophase"))
+  
+  if (!(method %in% c("bobyqa","newuoa")) && is.null(control$fnscale))
+    control$fnscale <- -wtotal/length(weights)
+  if (inherits(design, "twophase")) {
     data<-design$phase1$sample$variables
-  else 
+  } else { 
     data<-design$variables
-
-## Get the response variable
+  }
+  
+  ## Get the response variable
   nms<-names(formulas)
   if (nms[1]==""){
-	if (inherits(formulas[[1]],"formula"))
-	  y<-eval.parent(model.frame(formulas[[1]],data=data,na.action=na.pass))
-	else
-	  y<-eval(y,data,parent.frame())
-	formulas[1]<-NULL
-	if (FALSE && NCOL(y)>1) stop("Y has more than one column")
-    }   else {
-  	## one formula must have response
-	has.response<-sapply(formulas,length)==3
-	if (sum(has.response)!=1) stop("Need a response variable")
-	ff<-formulas[[which(has.response)]]
-	ff[[3]]<-1
-	y<-eval.parent(model.frame(ff,data=data,na.action=na.pass))
-	formulas[[which(has.response)]]<-delete.response(terms(formulas[[which(has.response)]]))
-        nms<-c("",nms)
+    if (inherits(formulas[[1]],"formula")) {
+      y<-eval.parent(model.frame(formulas[[1]],data=data,na.action=na.pass))
+    } else {
+      y<-eval(y,data,parent.frame())
+    }
+    formulas[1]<-NULL
+    if (FALSE && NCOL(y)>1) stop("Y has more than one column")
+  }   else {
+    ## one formula must have response
+    has.response<-sapply(formulas,length)==3
+    if (sum(has.response)!=1) stop("Need a response variable")
+    ff<-formulas[[which(has.response)]]
+    ff[[3]]<-1
+    y<-eval.parent(model.frame(ff,data=data,na.action=na.pass))
+    formulas[[which(has.response)]]<-delete.response(terms(formulas[[which(has.response)]]))
+    nms<-c("",nms)
   }
-
+  
   if(length(which(nms==""))>1) stop("Formulas must have names")
-
+  
   mf<-vector("list",length(formulas))
   vnms <- unique(do.call(c, lapply(formulas, all.vars)))
   uformula <- make.formula(vnms)
@@ -1694,305 +1750,153 @@ svymle<-function(loglike, gradient=NULL, design, formulas,
   wtotal<-sum(weights)
   
   Y<-mf[,1]
-  mm<-lapply(formulas,model.matrix, data=mf)
-
+  
+#  mm <- lapply(formulas,model.matrix, data=mf)
+  
+  mmFrame <- lapply(formulas,model.frame, data=mf)
+  mm = mapply(model.matrix, object = formulas, data=mmFrame, SIMPLIFY=FALSE)
+  mmOffset <- lapply(mmFrame, model.offset)
+  
+  # add a vector of zeros if there is no offset provided
+  noOffset = which(unlist(lapply(mmOffset, length))==0)
+  for(D in noOffset) {
+    mmOffset[[D]] =  rep(0, NROW(mm[[1]]))
+  }
+  
   ## parameter names
   parnms<-lapply(mm,colnames)
   for(i in 1:length(parnms))
-	parnms[[i]]<-paste(nms[i+1],parnms[[i]],sep=".")
+    parnms[[i]]<-paste(nms[i+1],parnms[[i]],sep=".")
   parnms<-unlist(parnms)
-
+  
   # maps position in theta to model matrices
   np<-c(0,cumsum(sapply(mm,NCOL)))
-
-
+  
+  
   objectivefn<-function(theta,...){
-     args<-vector("list",length(nms))
-     args[[1]]<-Y
-     for(i in 2:length(nms))
-	args[[i]]<-mm[[i-1]]%*%theta[(np[i-1]+1):np[i]]
-     names(args)<-nms
-     args<-c(args, ...)
-     sum(do.call("loglike",args)*weights)
+    args<-vector("list",length(nms))
+    args[[1]]<-Y
+    for(i in 2:length(nms))
+      args[[i]]<-mm[[i-1]]%*%theta[(np[i-1]+1):np[i]] + 
+          mmOffset[[i-1]]
+    names(args)<-nms
+    args<-c(args, ...)
+    sum(do.call("loglike",args)*weights)
   }
-
+  
   if (is.null(gradient)) {
-     grad<-NULL
+    grad<-NULL
   } else {  
-     fnargs<-names(formals(loglike))[-1]
-     grargs<-names(formals(gradient))[-1]
-     if(!identical(fnargs,grargs))
-       stop("loglike and gradient have different arguments.")
-     reorder<-na.omit(match(grargs,nms[-1]))
-     grad<-function(theta,...){
-       args<-vector("list",length(nms))
-       args[[1]]<-Y
-       for(i in 2:length(nms))
-	  args[[i]]<-drop(mm[[i-1]]%*%theta[(np[i-1]+1):np[i]])
-       names(args)<-nms
-       args<-c(args,...)
-       rval<-NULL
-       tmp<-do.call("gradient",args)
-       for(i in reorder){
-	   rval<-c(rval, colSums(as.matrix(tmp[,i]*weights*mm[[i]])))
-	}
-       drop(rval)
-     }
+    fnargs<-names(formals(loglike))[-1]
+    grargs<-names(formals(gradient))[-1]
+    if(!identical(fnargs,grargs))
+      stop("loglike and gradient have different arguments.")
+    reorder<-na.omit(match(grargs,nms[-1]))
+    grad<-function(theta,...){
+      args<-vector("list",length(nms))
+      args[[1]]<-Y
+      for(i in 2:length(nms))
+        args[[i]]<-drop(
+            mm[[i-1]]%*%theta[(np[i-1]+1):np[i]] +
+                mmOffset[[i-1]])
+      names(args)<-nms
+      args<-c(args,...)
+      rval<-NULL
+      tmp<-do.call("gradient",args)
+      for(i in reorder){
+        rval<-c(rval, colSums(as.matrix(tmp[,i]*weights*mm[[i]])))
+      }
+      drop(rval)
+    }
   }
-
+  
   theta0<-numeric(np[length(np)])
   if (is.list(start))
-      st<-do.call("c",start)
+    st<-do.call("c",start)
   else
-      st<-start
-
+    st<-start
+  
   if (length(st)==length(theta0)) {
-	theta0<-st
+    theta0<-st
   } else {
-	stop("starting values wrong length")
+    stop("starting values wrong length")
   }
-
+  
   if (method=="nlm"){
-      ff<-function(theta){
-          rval<- -objectivefn(theta)
-          if (is.na(rval)) rval<- -Inf
-          attr(rval,"gradient")<- -grad(theta)
-          rval
-      }
-      rval<-nlm(ff, theta0,hessian=TRUE)
-      if (rval$code>3) warning("nlm did not converge")
-      rval$par<-rval$estimate
-  } else {
-      rval<-optim(theta0, objectivefn, grad,control=control,
-              hessian=TRUE,method=method,...)
-      if (rval$conv!=0) warning("optim did not converge")
+    ff<-function(theta){
+      rval<- -objectivefn(theta)
+      if (is.na(rval)) rval<- -Inf
+      attr(rval,"gradient")<- -grad(theta)
+      rval
+    }
+    rval<-nlm(ff, theta0,hessian=TRUE)
+    if (rval$code>3) warning("nlm did not converge")
+    rval$par<-rval$estimate
+  } else if (method == "newuoa"){
+      rval<-minqa::uobyqa(theta0, function(par,...) -objectivefn(par,...), control=control, ...)
+      if(rval$ier>0) warning(rval$msg)
+      rval$hessian <- numDeriv::hessian(objectivefn, rval$par)
+  } else if (method == "bobyqa"){
+      if (is.list(lower)) lower<-do.call(c, lower)
+      if (is.list(upper)) upper<-do.call(c,upper)
+      rval<-minqa::bobyqa(theta0, function(par,...) -objectivefn(par,...), control=control,lower=lower,upper=upper, ...)
+      if(rval$ier>0) warning(rval$msg)
+      rval$hessian <- numDeriv::hessian(objectivefn,rval$par)
+  }else {
+    rval<-optim(theta0, objectivefn, grad,control=control,
+        hessian=TRUE,method=method,...)
+    if (rval$conv!=0) warning("optim did not converge")
   }
-
+  
+  
+  
   
-
-
   names(rval$par)<-parnms
   dimnames(rval$hessian)<-list(parnms,parnms)
-
+  
   if (is.null(gradient)) {
-	rval$invinf<-solve(-rval$hessian)
-	rval$scores<-NULL
-	rval$sandwich<-NULL
-    }  else {
-       theta<-rval$par
-       args<-vector("list",length(nms))
-       args[[1]]<-Y
-       for(i in 2:length(nms))
-	  args[[i]]<-drop(mm[[i-1]]%*%theta[(np[i-1]+1):np[i]])
-       names(args)<-nms
-       args<-c(args,...)
-       deta<-do.call("gradient",args)
-       rval$scores<-NULL
-       for(i in reorder)
-       	 rval$scores<-cbind(rval$scores,deta[,i]*weights*mm[[i]])
+    rval$invinf<-solve(-rval$hessian)
+    rval$scores<-NULL
+    rval$sandwich<-NULL
+  }  else {
+    theta<-rval$par
+    args<-vector("list",length(nms))
+    args[[1]]<-Y
+    for(i in 2:length(nms))
+      args[[i]]<-drop(mm[[i-1]]%*%theta[(np[i-1]+1):np[i]]+ mmOffset[[i-1]])
+    names(args)<-nms
+    args<-c(args,...)
+    deta<-do.call("gradient",args)
+    rval$scores<-NULL
+    for(i in reorder)
+      rval$scores<-cbind(rval$scores,deta[,i]*weights*mm[[i]])
+    
+    rval$invinf<-solve(-rval$hessian)
+    dimnames(rval$invinf)<-list(parnms,parnms)
+    
+    db<-rval$scores%*%rval$invinf
+    if (inherits(design,"survey.design2"))
+      rval$sandwich<-svyrecvar(db,design$cluster,design$strata, design$fpc, 
+          postStrata=design$postStrata)
+    else if (inherits(design, "twophase"))
+      rval$sandwich<-twophasevar(db,design)
+    else
+      rval$sandwich<-svyCprod(db,design$strata,design$cluster[[1]],
+          design$fpc, design$nPSU,
+          design$certainty, design$postStrata)
+    dimnames(rval$sandwich)<-list(parnms,parnms)
+  }
 
-       rval$invinf<-solve(-rval$hessian)
-       dimnames(rval$invinf)<-list(parnms,parnms)
-
-       db<-rval$scores%*%rval$invinf
-       if (inherits(design,"survey.design2"))
-         rval$sandwich<-svyrecvar(db,design$cluster,design$strata, design$fpc, 
-                               postStrata=design$postStrata)
-       else if (inherits(design, "twophase"))
-         rval$sandwich<-twophasevar(db,design)
-       else
-         rval$sandwich<-svyCprod(db,design$strata,design$cluster[[1]],
-                                 design$fpc, design$nPSU,
-                                 design$certainty, design$postStrata)
-       dimnames(rval$sandwich)<-list(parnms,parnms)
-     }
+  if (influence)
+      attr(rval,"influence")<-db
   rval$call<-match.call()
   rval$design<-design
   class(rval)<-"svymle"
   rval
-
+  
 }
 
 
-svymleOLD<-function(loglike, gradient=NULL, design, formulas,
-                 start=NULL, control=list(maxit=1000),
-                 na.action="na.fail", method=NULL,...){
-  if(is.null(method))
-    method<-if(is.null(gradient)) "Nelder-Mead" else "nlm"
-  
-  if (!inherits(design,"survey.design")) 
-	stop("design is not a survey.design")
-
-  weights<-1/design$prob
-  wtotal<-sum(weights)
-  if (is.null(control$fnscale))
-      control$fnscale<- -wtotal
-  if (inherits(design, "twophase"))
-    data<-design$phase1$sample$variables
-  else 
-    data<-design$variables
-
-## Get the response variable
-  nms<-names(formulas)
-  if (nms[1]==""){
-	if (inherits(formulas[[1]],"formula"))
-	  y<-eval.parent(model.frame(formulas[[1]],data=data,na.action=na.pass))
-	else
-	  y<-eval(y,data,parent.frame())
-	formulas[1]<-NULL
-	if (FALSE && NCOL(y)>1) stop("Y has more than one column")
-    }   else {
-  	## one formula must have response
-	has.response<-sapply(formulas,length)==3
-	if (sum(has.response)!=1) stop("Need a response variable")
-	ff<-formulas[[which(has.response)]]
-	ff[[3]]<-1
-	y<-eval.parent(model.frame(ff,data=data,na.action=na.pass))
-	formulas[[which(has.response)]]<-delete.response(terms(formulas[[which(has.response)]]))
-        nms<-c("",nms)
-  }
-
-  if(length(which(nms==""))>1) stop("Formulas must have names")
-  
-  
-  mf<-vector("list",length(formulas))
-  for(i in 1:length(formulas)){
-	mf[[i]]<-eval.parent(model.frame(formulas[[i]], data=data, na.action=na.pass))
-	}
-  notnulls<-sapply(mf,function(mfi) NCOL(mfi)!=0)
-  mf<-mf[notnulls]
-  if (any(notnulls))
-    mf<-as.data.frame(do.call("cbind",c(y,mf)))
-  else
-    mf<-y
-  names(mf)[1]<-"(Response)"
-  mf<-mf[,!duplicated(colnames(mf)),drop=FALSE]
-
-  mf<-get(na.action)(mf)  
-  nas<-attr(mf,"na.action")
-  if (length(nas))
-	design<-design[-nas,]
-
-  Y<-mf[,1]
-  mm<-lapply(formulas,model.matrix, data=mf)
-
-  ## parameter names
-  parnms<-lapply(mm,colnames)
-  for(i in 1:length(parnms))
-	parnms[[i]]<-paste(nms[i+1],parnms[[i]],sep=".")
-  parnms<-unlist(parnms)
-
-  # maps position in theta to model matrices
-  np<-c(0,cumsum(sapply(mm,NCOL)))
-
-
-  objectivefn<-function(theta,...){
-     args<-vector("list",length(nms))
-     args[[1]]<-Y
-     for(i in 2:length(nms))
-	args[[i]]<-mm[[i-1]]%*%theta[(np[i-1]+1):np[i]]
-     names(args)<-nms
-     args<-c(args, ...)
-     sum(do.call("loglike",args)*weights)
-  }
-
-  if (is.null(gradient)) {
-     grad<-NULL
-  } else {  
-     fnargs<-names(formals(loglike))[-1]
-     grargs<-names(formals(gradient))[-1]
-     if(!identical(fnargs,grargs))
-       stop("loglike and gradient have different arguments.")
-     reorder<-na.omit(match(grargs,nms[-1]))
-     grad<-function(theta,...){
-       args<-vector("list",length(nms))
-       args[[1]]<-Y
-       for(i in 2:length(nms))
-	  args[[i]]<-drop(mm[[i-1]]%*%theta[(np[i-1]+1):np[i]])
-       names(args)<-nms
-       args<-c(args,...)
-       rval<-NULL
-       tmp<-do.call("gradient",args)
-       for(i in reorder){
-	   rval<-c(rval, colSums(as.matrix(tmp[,i]*weights*mm[[i]])))
-	}
-       drop(rval)
-     }
-  }
-
-  theta0<-numeric(np[length(np)])
-  if (is.list(start))
-      st<-do.call("c",start)
-  else
-      st<-start
-
-  if (length(st)==length(theta0)) {
-	theta0<-st
-  } else {
-	stop("starting values wrong length")
-  }
-
-  if (method=="nlm"){
-      ff<-function(theta){
-          rval<- -objectivefn(theta)
-          if (is.na(rval)) rval<- -Inf
-          attr(rval,"grad")<- -grad(theta)
-          rval
-      }
-      rval<-nlm(ff, theta0,hessian=TRUE)
-      if (rval$code>3) warning("nlm did not converge")
-      rval$par<-rval$estimate
-  } else {
-      rval<-optim(theta0, objectivefn, grad,control=control,
-              hessian=TRUE,method=method,...)
-      if (rval$conv!=0) warning("optim did not converge")
-  }
-
-  
-
-
-  names(rval$par)<-parnms
-  dimnames(rval$hessian)<-list(parnms,parnms)
-
-  if (is.null(gradient)) {
-	rval$invinf<-solve(-rval$hessian)
-	rval$scores<-NULL
-	rval$sandwich<-NULL
-    }  else {
-       theta<-rval$par
-       args<-vector("list",length(nms))
-       args[[1]]<-Y
-       for(i in 2:length(nms))
-	  args[[i]]<-drop(mm[[i-1]]%*%theta[(np[i-1]+1):np[i]])
-       names(args)<-nms
-       args<-c(args,...)
-       deta<-do.call("gradient",args)
-       rval$scores<-NULL
-       for(i in reorder)
-       	 rval$scores<-cbind(rval$scores,deta[,i]*weights*mm[[i]])
-
-       rval$invinf<-solve(-rval$hessian)
-       dimnames(rval$invinf)<-list(parnms,parnms)
-
-       db<-rval$scores%*%rval$invinf
-       if (inherits(design,"survey.design2"))
-         rval$sandwich<-svyrecvar(db,design$cluster,design$strata, design$fpc, 
-                               postStrata=design$postStrata)
-       else if (inherits(design, "twophase"))
-         rval$sandwich<-twophasevar(db,design)
-       else
-         rval$sandwich<-svyCprod(db,design$strata,design$cluster[[1]],
-                                 design$fpc, design$nPSU,
-                                 design$certainty, design$postStrata)
-       dimnames(rval$sandwich)<-list(parnms,parnms)
-     }
-  rval$call<-match.call()
-  rval$design<-design
-  class(rval)<-"svymle"
-  rval
-
-}
-
 coef.svymle<-function(object,...) object$par
 
 vcov.svymle<-function(object,stderr=c("robust","model"),...) {
